@@ -344,6 +344,9 @@ macro_rules! try_or_err {
 /// ```
 #[macro_export]
 macro_rules! invariant {
+    ($invariant: expr $(,)?) => {
+        $crate::invariant!($invariant, $crate::VipersError::InvariantFailed);
+    };
     ($invariant: expr, $err_code: ident $(,)?) => {
         $crate::invariant!($invariant, crate::ErrorCode::$err_code);
     };
@@ -355,7 +358,8 @@ macro_rules! invariant {
     };
     ($invariant:expr, $err:expr, $msg: expr $(,)?) => {
         if !($invariant) {
-            msg!("Invariant failed: {:?}", $err);
+            msg!($msg);
+            msg!(stringify!($err));
             $crate::throw_err!($crate::VipersError::InvariantFailed);
         }
     };
